@@ -25,11 +25,6 @@ class Parser:
             self.elements = self.construct_elements(
                 self.elements, inline_element_type.pattern, inline_element_type)
 
-        # Replace all line breaks at the beginning or end of strings with `<br>`
-        for i, element in enumerate(self.elements):
-            if isinstance(element, str):
-                self.elements[i] = re.sub(r'[ \t]*\n', '<br>', element)
-
         # Only the form elements
         self.form_elements = [
             e for e in self.elements
