@@ -167,7 +167,7 @@ html = """
         </head>
 
         <body>
-            <form id="markdown-form">
+            <form id="markdown-form" onsubmit="return false">
                 (( body ))
             </form>
 
